import { Component, OnInit, OnDestroy, ViewChild } from '@angular/core';
import { TokenService } from 'src/app/services/token.service';
import { Router } from '@angular/router';
import { environment } from 'src/environments/environment';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { takeWhile } from 'rxjs/operators';
import { AlertService } from 'src/app/services/alert.service';
import {MatMenuModule, MatMenuTrigger} from '@angular/material/menu';

@Component({
  selector: 'app-layout',
  templateUrl: './layout.component.html',
  styleUrls: ['./layout.component.css']
})
export class LayoutComponent implements OnInit, OnDestroy {

  user: any;
  private alive = true;
  remainders = [];
  menu = '';
  isCollapsed = false;
  err: any;
  msg: any;
  authToken: any;

  constructor(
    private token: TokenService,
    private router: Router,
    private http: HttpClient,
    private as: AlertService,
  ) {}

  ngOnInit() {
    this.getUser();
  }

  errMsg() {
    this.err = this.as.errMsg();
    return this.err;
  }

  successMsg() {
    this.msg = this.as.successMsg();
    return this.msg;
  }

  reqfullscreen() {
    // tslint:disable-next-line: deprecation
    if (document.fullscreen) {
      document.exitFullscreen();
    } else {
      document.documentElement.requestFullscreen();
    }
  }

  getRemaindersForCounsellors() {
    // this.authToken = this.token.getToken();
    // const header: HttpHeaders = new HttpHeaders().set('Authorization', this.authToken);
    this.http
      .get(`${environment.url}/remainders/get-remainders/${this.user.username}`)
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          if (resp.success) {
            this.remainders = resp.remainders;
            // console.log(this.remainders);
          }
        },
        err => {
          // console.log(err);
        }
      );
  }

  openNav() {
    this.menu = this.menu === 'is-collapsed' ? '' : 'is-collapsed';
  }

  openSettingPopup() {
    this.menu = this.menu === 'is-collapsed' ? '' : 'is-collapsed';
  }

  getUser() {
    this.user = this.token.getUser();
    this.user.name = this.user.name.split(' ')[0];
    // if (this.user.role == 'counsellor') {
    this.getRemaindersForCounsellors();
    // }
    // // console.log(this.user);
  }

  logout() {
    localStorage.clear();
    this.router.navigate(['/login']);
  }

  ngOnDestroy() {
    this.alive = false;
  }

}
