import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { TokenService } from 'src/app/services/token.service';
import { environment } from 'src/environments/environment';
import { takeWhile } from 'rxjs/operators';
import { Router } from '@angular/router';
import Swal from 'sweetalert2';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css']
})
export class LoginComponent implements OnInit, OnDestroy {
  username: any;
  password: any;
  loading: Boolean = false;

  private alive = true;
  constructor(
    private http: HttpClient,
    private router: Router,
    private token: TokenService
  ) {}

  ngOnInit() {
    if (this.token.getToken()) {
      this.router.navigate(['/view/view-leads']);
    }
  }

  Login() {
    this.loading = true;
    let userdata = {
      username: this.username,
      password: this.password
    };

    this.http
      .post(`${environment.url}/user/login`, userdata)
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          this.loading = false;
          if (resp.success) {
            this.AlertSuccessMsg(resp.msg);
            this.token.setToken(resp.token);
            this.token.setUser(resp.user);
            this.router.navigate(['/dashboard']);
          } else {
            this.AlertErrorMsg(resp.msg);
          }
        },
        err => {
          this.loading = false;
          this.AlertErrorMsg(err.msg);
          // console.log(err);
        }
      );
  }

  AlertSuccessMsg(msg) {
    Swal.fire({
      position: 'top-end',
      type: 'success',
      title: 'Congratulations',
      showConfirmButton: false,
      timer: 3000,
      html: `${msg}`
    });
  }

  AlertErrorMsg(msg) {
    Swal.fire({
      position: 'top-end',
      type: 'error',
      title: 'Oops...',
      showConfirmButton: false,
      timer: 3000,
      html: `${msg}`
    });
  }

  ngOnDestroy() {
    this.alive = false;
  }
}
