import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { takeWhile } from 'rxjs/operators';
import { TokenService } from 'src/app/services/token.service';
import { AnimationService } from 'src/app/services/animation.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-counsellor',
  templateUrl: './counsellor.component.html',
  styleUrls: ['./counsellor.component.css']
})
export class CounsellorComponent implements OnInit, OnDestroy {

  private alive = true;
  authToken: any;
  counsellors: any;
  counsid: any;

  constructor(
    private http: HttpClient,
    private token: TokenService,
    private as: AnimationService,
    private router: Router,
  ) {}

  ngOnInit() {
    this.getCounsellors();
    this.as.hide();
  }

  getCounsellors() {
    this.authToken = this.token.getToken();
    const header: HttpHeaders = new HttpHeaders().set('Authorization', this.authToken);
    this.http
      .get(`${environment.url}/user/getCounsellors`, {headers: header})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          this.counsellors = resp.counsellors;
          console.log(this.counsellors);
        },
        err => {
          // console.log(err);
        }
      );
  }

  onCounsRowSelect(event: any) {
    // console.log(event.data);
    this.counsid = event._id;
    console.log(this.counsid);
    this.router.navigate([`couns-detail/${this.counsid}`]);
  }

  ngOnDestroy() {
    this.alive = false;
    this.as.show();
  }

}
