import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { takeWhile, filter } from 'rxjs/operators';
import { TokenService } from 'src/app/services/token.service';
import { AnimationService } from 'src/app/services/animation.service';
import { Router } from '@angular/router';


@Component({
  selector: 'app-manager',
  templateUrl: './manager.component.html',
  styleUrls: ['./manager.component.css'],
})
export class ManagerComponent implements OnInit, OnDestroy {

  private alive = true;
  authToken: any;
  managers: any;
  managerid: any;

  constructor(
    private http: HttpClient,
    private token: TokenService,
    private as: AnimationService,
    private router: Router
  ) {}

  ngOnInit() {
    this.getManagers();
    this.as.hide();
  }

  getManagers() {
    this.authToken = this.token.getToken();
    const header: HttpHeaders = new HttpHeaders().set('Authorization', this.authToken);
    this.http
      .get(`${environment.url}/user/getManagers`, {headers: header})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          this.managers = resp.managers;
          console.log(this.managers);
        },
        err => {
          // console.log(err)
        }
      );
  }

  onManagerRowSelect(event: any) {
    // console.log(event.data);
    this.managerid = event._id;
    console.log(this.managerid);
    this.router.navigate([`manager-detail/${this.managerid}`]);
  }

  ngOnDestroy() {
    this.alive = false;
    this.as.show();
  }

}
